@@ -1,10 +1,10 @@
 import logging
 
-from . import album, login, lyric, mv, search, singer, song, songlist, top, user
+from . import album, comment, login, lyric, mv, search, singer, song, songlist, top, user
 from .utils.credential import Credential
 from .utils.session import Session, get_session, set_session
 
-__version__ = "0.3.4"
+__version__ = "0.3.5"
 
 logger = logging.getLogger("qqmusicapi")
 
@@ -13,6 +13,7 @@ __all__ = [
     "Credential",
     "Session",
     "album",
+    "comment",
     "get_session",
     "login",
     "lyric",
